@@ -59,12 +59,13 @@ var methods = {
         }, options);
         // Default button settings
         var default_button_settings = {
+            "id" : '',
             "name" : '',
             "funcname" : 'common',
             "method" : 'syntax',
             "classname" : '',
             "key" : false,
-            "char" : false,
+            "linechar" : false,
             "url" : false,
             "placeholder" : '',
             "begin_with" : false,
@@ -84,7 +85,7 @@ var methods = {
             }
             
             var input_source = $(this), // this is allways the input source from where is created djangocodemirror
-                djangocodemirror_key = "djangocodemirror-id-" + (input_source.attr('id')||'default'), // djangocodemirror instance ID
+                instance_id = "dcm-" + (input_source.attr('id')||'default'), // djangocodemirror instance ID
                 container = $("<div class=\"DjangoCodeMirror\"></div>"),
                 header = $("<div class=\"DjangoCodeMirror_menu\"><ul></ul><div class=\"cale\"></div></div>"),
                 footer = $("<div class=\"DjangoCodeMirror_tabs\"><ul></ul><div class=\"cale\"></div></div>"),
@@ -112,12 +113,17 @@ var methods = {
             // Build CodeMirror
             var codemirror_instance = CodeMirror.fromTextArea(this, settings);
             // Force some certain key biding
+            
             codemirror_instance.setOption('extraKeys', {
                 "Tab": "indentMore", 
                 "Shift-Tab": "indentLess",
+                
+                // TODO: this needs changes, as the buttons are not using the same CSS class anymore, 
+                // and they have now a internal id
+                
                 // Quicksave keybind should be done along with the rest of buttons, not here
-                "Ctrl-S": function(cm){ cm.save(); $('.buttonQuickSave').trigger('click'); },
-                "Cmd-S": function(cm){ cm.save(); $('.buttonQuickSave').trigger('click'); }
+                "Ctrl-S": function(cm){ cm.save(); $('#'+instance_id+'-QuickSave').trigger('click'); },
+                "Cmd-S": function(cm){ cm.save(); $('#'+instance_id+'-QuickSave').trigger('click'); }
             });
             
             // Enable the cursor activy function
@@ -127,7 +133,7 @@ var methods = {
 
             // Attach element's data
             input_source.data("djangocodemirror", {
-                "key" : djangocodemirror_key,
+                "instance_id" : instance_id,
                 "container" : container,
                 "codemirror" : codemirror_instance,
                 "settings": settings
@@ -188,7 +194,7 @@ var methods = {
             var input_source = $(this),
                 instance_data = input_source.data("djangocodemirror"),
                 accesskey = (button_settings.key) ? ' accesskey="'+button_settings.key+'"' : '',
-                button = $('<li class="button '+button_settings.classname+'"><a'+accesskey+' title="'+safegettext(button_settings.name)+'">'+safegettext(button_settings.name)+'</a></li>');
+                button = $('<li id="'+instance_data.instance_id+'-'+button_settings.id+'" class="button '+button_settings.classname+'"><a'+accesskey+' title="'+safegettext(button_settings.name)+'">'+safegettext(button_settings.name)+'</a></li>');
             
             button.appendTo('.DjangoCodeMirror_menu ul', instance_data.container);
             if(button_settings.method == 'internal') {
@@ -223,14 +229,14 @@ var events = {
         // Update the undo/redo buttons class from history items
         var histo = instance_data.codemirror.historySize();
         if(histo.undo>0) {
-            $(".DjangoCodeMirror_menu .buttonUndo", instance_data.container).addClass("active").removeClass("inactive");
+            $("#"+instance_data.instance_id+"-Undo").addClass("active").removeClass("inactive");
         } else {
-            $(".DjangoCodeMirror_menu .buttonUndo", instance_data.container).addClass("inactive").removeClass("active");
+            $("#"+instance_data.instance_id+"-Undo").addClass("inactive").removeClass("active");
         }
         if(histo.redo>0) {
-            $(".DjangoCodeMirror_menu .buttonRedo", instance_data.container).addClass("active").removeClass("inactive");
+            $("#"+instance_data.instance_id+"-Redo").addClass("active").removeClass("inactive");
         } else {
-            $(".DjangoCodeMirror_menu .buttonRedo", instance_data.container).addClass("inactive").removeClass("active");
+            $("#"+instance_data.instance_id+"-Redo").addClass("inactive").removeClass("active");
         }
         // Update the highlight
         if(instance_data.settings.enable_active_line){
@@ -293,18 +299,18 @@ var events = {
                 }
             },
             success: function(data) {
-                $(".DjangoCodeMirror_menu .buttonQuickSave", instance_data.container).removeClass("ready");
-                $(".DjangoCodeMirror_menu .buttonQuickSave", instance_data.container).removeClass("error");
+                $("#"+instance_data.instance_id+"-QuickSave", instance_data.container).removeClass("ready");
+                $("#"+instance_data.instance_id+"-QuickSave", instance_data.container).removeClass("error");
                 if(data['status']=='form_invalid') {
-                    $(".DjangoCodeMirror_menu .buttonQuickSave", instance_data.container).addClass("error");
+                    $("#"+instance_data.instance_id+"-QuickSave", instance_data.container).addClass("error");
                     createGrowl(instance_data.container, "warning", safegettext("Validation error"), data["errors"]["content"].join("<br/>"), false);
                 } else {
                     createGrowl(instance_data.container, "success", safegettext("Success"), safegettext("Successful save"), false);
                 }
             },
             error: function(jqXHR, textStatus, errorThrown) {
-                $(".DjangoCodeMirror_menu .buttonQuickSave", instance_data.container).removeClass("ready");
-                $(".DjangoCodeMirror_menu .buttonQuickSave", instance_data.container).addClass("error");
+                $("#"+instance_data.instance_id+"-QuickSave", instance_data.container).removeClass("ready");
+                $("#"+instance_data.instance_id+"-QuickSave", instance_data.container).addClass("error");
                 createGrowl(instance_data.container, "warning", textStatus, errorThrown, false);
             }
         });
@@ -548,7 +554,7 @@ var events = {
             url: instance_data.settings.settings_url,
             success: function(data) {
                 instance_data.container.prepend(panel);
-                $(".DjangoCodeMirror_menu .buttonSettings", instance_data.container).removeClass("error");
+                $("#"+instance_data.instance_id+"-Settings", instance_data.container).removeClass("error");
                 panel.append(data);
                 $("form", panel).css({
                    "overflow": "auto",
@@ -563,7 +569,7 @@ var events = {
                 $(window).bind("resize.djc_settings", { "input_source": input_source, "panel": panel }, events.resize_settings);
             },
             error: function(jqXHR, textStatus, errorThrown) {
-                $(".DjangoCodeMirror_menu .buttonSettings", instance_data.container).addClass("error");
+                $("#"+instance_data.instance_id+"-Settings", instance_data.container).addClass("error");
                 createGrowl(instance_data.container, "warning", textStatus, errorThrown, false);
             }
         });
@@ -622,19 +628,19 @@ var coreutils = {
     * This is where buttons should be deleted or modified from defined settings
     */
     buttons_preprocessing: function(settings, buttons) {
-        // Available buttons indexation on classname
+        // Available buttons indexation on id
         var button_indexes = {};
         $.each(buttons, function(item_index, item_value) {
             if(!item_value.separator){
-                button_indexes[item_value.classname] = item_index;
+                button_indexes[item_value.id] = item_index;
             }
         });
         // Delete button from registry if option is disabled
         // Assume that there are two buttons followed by a separator
-        if( button_indexes['buttonFullscreenEnter'] != undefined && button_indexes['buttonFullscreenEnter'] != null){
+        if( button_indexes['FullscreenEnter'] != undefined && button_indexes['FullscreenEnter'] != null){
             if(!settings.fullscreen){
-                var pos_enter = button_indexes['buttonFullscreenEnter'];
-                var pos_exit = button_indexes['buttonFullscreenExit'];
+                var pos_enter = button_indexes['FullscreenEnter'];
+                var pos_exit = button_indexes['FullscreenExit'];
                 delete buttons[pos_enter];
                 delete buttons[pos_exit];
                 if(buttons[pos_exit+1].separator) {
@@ -643,8 +649,8 @@ var coreutils = {
             }
         }
         // Quicksave button
-        if( button_indexes['buttonQuickSave'] != undefined && button_indexes['buttonQuickSave'] != null){
-            var pos = button_indexes['buttonQuickSave'];
+        if( button_indexes['QuickSave'] != undefined && button_indexes['QuickSave'] != null){
+            var pos = button_indexes['QuickSave'];
             if(settings.quicksave_url){
                 buttons[pos].quicksave_url = settings.quicksave_url;
                 buttons[pos].quicksave_datas = settings.quicksave_datas;
@@ -658,9 +664,9 @@ var coreutils = {
         }
         // Undo/Redo buttons
         // Assume that there are two buttons followed by a separator
-        if( button_indexes['buttonUndo'] != undefined && button_indexes['buttonUndo'] != null){
-            var pos_undo = button_indexes['buttonUndo'];
-            var pos_redo = button_indexes['buttonRedo'];
+        if( button_indexes['Undo'] != undefined && button_indexes['Undo'] != null){
+            var pos_undo = button_indexes['Undo'];
+            var pos_redo = button_indexes['Redo'];
             if(!settings.undo_buttons){
                 delete buttons[pos_undo];
                 delete buttons[pos_redo];
@@ -670,8 +676,8 @@ var coreutils = {
             }
         }
         // Help link if setted
-        if( button_indexes['buttonHelp'] != undefined && button_indexes['buttonHelp'] != null){
-            var pos = button_indexes['buttonHelp'];
+        if( button_indexes['Help'] != undefined && button_indexes['Help'] != null){
+            var pos = button_indexes['Help'];
             if( settings.help_link ){
                 buttons[pos].url = settings.help_link;
             } else {
@@ -679,8 +685,8 @@ var coreutils = {
             }
         }
         // Help link if setted
-        if( button_indexes['buttonSettings'] != undefined && button_indexes['buttonSettings'] != null){
-            var pos = button_indexes['buttonSettings'];
+        if( button_indexes['Settings'] != undefined && button_indexes['Settings'] != null){
+            var pos = button_indexes['Settings'];
             if(!settings.settings_url){
                 delete buttons[pos];
             }
